pub enum PegValue {
Best,
Mid,
}Expand description
The different types of valid peg values.
Variants
Best
The best Bid for a buy order and the best Ask for a sell order.
Mid
The mid-point price between the best bid and the best ask.