pub struct OptionSpreadStrikesQuery {
pub underlying: String,
pub spread_type: OptionSpreadType,
pub strike_interval: i32,
pub expiration: Option<String>,
pub expiration2: Option<String>,
}Expand description
The query required to fetch OptionSpreadStrikes.
Fields
underlying: StringThe symbol for the underlying security on which the option contracts are based.
NOTE: The underlying symbol must be an equity or index.
spread_type: OptionSpreadTypeThe type of spread market_data::OptionSpreadType
strike_interval: i32The desired interval between the strike prices in a spread. It must be greater than or equal to 1. A value of 1 uses consecutive strikes; a value of 2 skips one between strikes; and so on.
expiration: Option<String>The date on which the option contract expires; must be a valid expiration date.
NOTE: Defaults to the next contract expiration date.
expiration2: Option<String>The second contract expiration date required for Calendar and Diagonal spreads.