pub enum StreamOptionChainResp {
OptionChain(Box<OptionChain>),
Heartbeat(Heartbeat),
Status(StreamStatus),
Error(ErrorResp),
}Expand description
The TradeStation API Response for streaming an options chain.
Variants
OptionChain(Box<OptionChain>)
The main response which contains the option chain data.
Heartbeat(Heartbeat)
Periodic signal to know the connection is still alive.
Status(StreamStatus)
Signal sent on state changes in the stream (closed, opened, paused, resumed).
Error(ErrorResp)
Response for when an error was encountered, with details on the error.